summaryrefslogtreecommitdiffstats
path: root/modules/notification/notification.go
diff options
context:
space:
mode:
authorzeripath <art27@cantab.net>2020-04-30 21:24:08 +0100
committerGitHub <noreply@github.com>2020-04-30 21:24:08 +0100
commit4974b7c120102b49548197e58c7a58181ba52170 (patch)
treea7769043d9c541bfd1af688ffa7fa76b75b99223 /modules/notification/notification.go
parentab69b9b1a60a83cf2b5d6c021da0cb35540df10f (diff)
downloadgitea-4974b7c120102b49548197e58c7a58181ba52170.tar.gz
gitea-4974b7c120102b49548197e58c7a58181ba52170.zip
Fix spelling mistake with Rewiew (#11262)
Signed-off-by: Andrew Thornton <art27@cantab.net>
Diffstat (limited to 'modules/notification/notification.go')
-rw-r--r--modules/notification/notification.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/modules/notification/notification.go b/modules/notification/notification.go
index 95117c1f3e..d120246634 100644
--- a/modules/notification/notification.go
+++ b/modules/notification/notification.go
@@ -150,10 +150,10 @@ func NotifyIssueChangeAssignee(doer *models.User, issue *models.Issue, assignee
}
}
-// NotifyPullRewiewRequest notifies Request Review change
-func NotifyPullRewiewRequest(doer *models.User, issue *models.Issue, reviewer *models.User, isRequest bool, comment *models.Comment) {
+// NotifyPullReviewRequest notifies Request Review change
+func NotifyPullReviewRequest(doer *models.User, issue *models.Issue, reviewer *models.User, isRequest bool, comment *models.Comment) {
for _, notifier := range notifiers {
- notifier.NotifyPullRewiewRequest(doer, issue, reviewer, isRequest, comment)
+ notifier.NotifyPullReviewRequest(doer, issue, reviewer, isRequest, comment)
}
}